#
# spec file for package python-python-bidi
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-python-bidi
Version:        0.6.6
Release:        1.1
Summary:        BiDi layout algorithm
License:        LGPL-3.0-only
Group:          Development/Languages/Python
URL:            https://github.com/MeirKriheli/python-bidi
Source:         https://files.pythonhosted.org/packages/source/p/python_bidi/python_bidi-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  %{python_module maturin > 1}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  cargo
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  rust
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
A pure python implementation of the BiDi layout algorithm.

%prep
%autosetup -a1 -p1 -n python_bidi-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pybidi
%python_expand %fdupes %{buildroot}%{$python_sitearch}

#%%check
#%%pyunittest_arch -v
#%%pytest

%post
%python_install_alternative pybidi

%postun
%python_uninstall_alternative pybidi

%files %{python_files}
%doc AUTHORS.rst CHANGELOG.rst README.rst
%license COPYING COPYING.LESSER
%python_alternative %{_bindir}/pybidi
%{python_sitearch}/bidi
%{python_sitearch}/python_bidi-%{version}.dist-info

%changelog
* Mon Mar 10 2025 Matej Cepl <mcepl@cepl.eu>
- python-maturin is not required for running of the package.
- python-six it not required at all.
* Mon Mar 10 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.6.6
  * Upgraded to macos-13 runner (as 12 is not available anymore).
- from version 0.6.5
  * Revert "Added pypy3.11 to build"
- from version 0.6.4
  * Added pypy3.11 to build
  * Removed pypy3.8 from build, not suppurted
  * Bumped pyo3 to 0.23.3, drops pypy3.7 and pypy3.8
  * Bumped unicode-bidi to 0.3.18  closes #28
- from version 0.6.3
  * Updated pyo3 to 0.22.4
  * Python 3.13 wheels are finally working
- from version 0.6.2
  * Added check-latest to the build
- from version 0.6.1
  * Bumped to build Python 3.13 wheels
- from version 0.6.0
  * Added implemention selection (Python or Rust) to pybidi cli,
    respecting backward comapt
  * Restored older algorithm, supports both implementations closes #25
  * Modernize and simplify Python code (Thanks Christian Clauss)
- from version 0.5.2
  * Added get_base_level backward compat
  * docstring cleanup
- from version 0.5.1
  * Added compat for older import, closes #23
  * Updated copyrights
- from version 0.5.0
  * Switched to using Rust based unicode-bidi using PyO3
  * Dropped Python < 3.9 support
  * Removed "upper_is_rtl"
  * Import of ``get_display`` changed to ``from bidi import get_display``
- Add cargo to BuildRequires
- Add rust to BuildRequires
- Disable testsuite for the time being which fails to import bidi.bidi
- Enable vendoring for Rust building dependencies
- Switch build architecture to binary
- Switch build system from setuptools to pyproject.toml
  * Add python-pip and python-wheel to BuildRequires
  * Replace %%python_build with %%pyproject_wheel
  * Replace %%python_install with %%pyproject_install
  * Update name for dist directory in %%files section
- Switch package to modern Python Stack on SLE-15
  * Use Python 3.11 on SLE-15 by default
  * Drop support for older Python versions
- Update BuildRequires and Requires from pyproject.toml
* Fri May 28 2021 pgajdos@suse.com
- %%check: use %%pyunittest rpm macro
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon Jul 22 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.4.2:
  * Merged Fix for mixed RTL and numbers, Thanks Just van Rossum
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sat May 26 2018 toddrme2178@gmail.com
- Initial version
